<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Buruz</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Fitxategi-kudeatzaile arina</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programazioa:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="144"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>Authors</source>
        <translation>Egileak</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="74"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="135"/>
        <source>License</source>
        <translation>Lizentzia</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>Euskarri aldagarria txertatzen da</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Kendu daitekeen euskarria txertatu da&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Euskarri mota:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>Detektatzen...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>Mesedez, hautatu egin nahi duzun ekintza:</translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation>Mailan izena aldatu</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="47"/>
        <source># will be replaced by numbers starting with:</source>
        <translation># honekin hasten diren zenbakiekin ordezkatuko da:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="80"/>
        <source>Pad numbers with zero if possible</source>
        <translation>Zerodun zenbakiak, ahal bada</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="87"/>
        <source>Use localized numbers</source>
        <translation>Erabili lokalizatutako zenbakiak</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="27"/>
        <source>Rename selected files to:</source>
        <translation>Aldatu izena hautatutako fitxategiak honela:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="40"/>
        <source>Name#</source>
        <translation>Izena#</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>Konektatu urruneko zerbitzariarekin</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="80"/>
        <source>Anonymous &amp;login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../connect.ui" line="90"/>
        <source>Login as &amp;user:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../connect.ui" line="29"/>
        <source>Specify remote folder to connect</source>
        <translation>Zehaztu urruneko karpeta konektatzeko</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="36"/>
        <source>Type:</source>
        <translation>Mota:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="56"/>
        <source>Port:</source>
        <translation>Portua:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="70"/>
        <source>Path:</source>
        <translation>Bidea:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="46"/>
        <source>Host:</source>
        <translation>Ostalaria:</translation>
    </message>
</context>
<context>
    <name>DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.ui" line="14"/>
        <source>Create Launcher</source>
        <translation>Sortu abiarazlea</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="38"/>
        <source>Name:</source>
        <translation>Izena:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="45"/>
        <source>Specific name of this launcher.</source>
        <translation>Abiarazle honen izen zehaztu.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="58"/>
        <source>Description:</source>
        <translation>Deskribapena:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="65"/>
        <source>A short description or generic name, like &quot;Web Browser&quot; or &quot;Home Directory&quot;.

It can be left empty.</source>
        <translation>Deskribapen laburra edo izen generikoa, adibidez, &quot;Web arakatzailea&quot; edo &quot;Home Directory&quot;.


Hutsik utz daiteke.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="77"/>
        <source>Comment:</source>
        <translation>Iruzkina:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="84"/>
        <source>A short comment.

It can be left empty.</source>
        <translation>Iruzkin labur bat.

Hutsik utz daiteke.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="117"/>
        <source>Command:</source>
        <translation>Agindua:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="133"/>
        <location filename="../desktopentrydialog.ui" line="164"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="142"/>
        <source>Icon:</source>
        <translation>Ikonoa:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="151"/>
        <source>Icon to display in file manager, menus, etc.</source>
        <translation>Fitxategi-kudeatzailean, menuetan, etab. bistaratzeko ikonoa.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="173"/>
        <location filename="../desktopentrydialog.ui" line="183"/>
        <source>Run in terminal?</source>
        <translation>Terminalean exekutatu?</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="176"/>
        <source>Terminal:</source>
        <translation>Terminala:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="186"/>
        <source>Whether the launched program should run in a terminal window.</source>
        <translation>Abiarazitako programa terminaleko leiho batean exekutatu behar den ala ez.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="190"/>
        <source>No</source>
        <translation>Ez</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="195"/>
        <source>Yes</source>
        <translation>Bai</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="203"/>
        <source>Type:</source>
        <translation>Mota:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="210"/>
        <source>Whether this is a link or executes a command.</source>
        <translation>Esteka den edo komando bat exekutatzen duen.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="214"/>
        <source>Application</source>
        <translation>Aplikazioa</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="219"/>
        <source>Link</source>
        <translation>Esteka</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="96"/>
        <source>Categories:</source>
        <translation>Kategoriak:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="103"/>
        <source>Semicolon separated categories in which the entry should be shown if it is used by the DE&apos;s main menu (e.g., when put inside ~/.local/share/applications).

It is needed only when you want to use the created file in the main menu. Otherwise, you could leave it empty.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Mahaigaina</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Mahaigaineko karpeta:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>Irudi fitxategia</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Karpeta-bidea</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Mahaigaineko Hobespenak</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="338"/>
        <location filename="../desktop-preferences.ui" line="344"/>
        <source>Background</source>
        <translation>Aurrekariak</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="385"/>
        <source>Wallpaper mode:</source>
        <translation>Horma-paper modua:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="408"/>
        <source>Wallpaper image file:</source>
        <translation>Horma-irudiaren fitxategia:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="350"/>
        <source>Select background color:</source>
        <translation>Hautatu atzeko planoko kolorea:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="417"/>
        <source>Image file</source>
        <translation>Irudi fitxategia</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="423"/>
        <source>Image file path</source>
        <translation>Irudi fitxategiaren bidea</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="430"/>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Icons</source>
        <translation>Ikonoak</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="36"/>
        <source>Icon size:</source>
        <translation>Ikonoaren tamaina:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="49"/>
        <source>Label Text</source>
        <translation>Etiketa testua</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="113"/>
        <source>Select shadow color:</source>
        <translation>Hautatu itzal-kolorea:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="61"/>
        <source>Select font:</source>
        <translation>Hautatu letra-tipoa:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>Orokorra</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="87"/>
        <source>Select text color:</source>
        <translation>Hautatu testuaren kolorea:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="136"/>
        <source>Spacing</source>
        <translation>Tartea</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="145"/>
        <source>Minimum item margins:</source>
        <translation>Elementuaren gutxieneko marjinak:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="152"/>
        <source>3 px by default.</source>
        <translation>3 px lehenespenez.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="155"/>
        <location filename="../desktop-preferences.ui" line="179"/>
        <location filename="../desktop-preferences.ui" line="237"/>
        <location filename="../desktop-preferences.ui" line="249"/>
        <location filename="../desktop-preferences.ui" line="275"/>
        <location filename="../desktop-preferences.ui" line="287"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="168"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="175"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>1 px lehenespenez.
3 testu-lerroetarako tarte bat ere gordetzen da.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="192"/>
        <source>Lock</source>
        <translation>Blokeatu</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="230"/>
        <source>Margins of work area:</source>
        <translation>Lan-eremuaren marjinak:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="303"/>
        <source>By default, desktop folders will be opened in PCManFM-Qt if they
are left clicked, even when it is not the default file manager.</source>
        <translation>Lehenespenez, mahaigaineko karpetak PCManFM-Qt-en irekiko dira baldin badira
ezkerreko klik egiten dira, fitxategi-kudeatzaile lehenetsia ez denean ere.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="307"/>
        <source>Open desktop folders in default file manager by left clicking</source>
        <translation>Ireki mahaigaineko karpetak fitxategi-kudeatzaile lehenetsian ezkerreko klik eginez</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="314"/>
        <source>Make all items stick to their positions</source>
        <translation>Egin elementu guztiak beren posizioetara itsatsi</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="373"/>
        <source>Wallpaper</source>
        <translation>Horma-papera</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="439"/>
        <source>Transform image based on EXIF data</source>
        <translation>Eraldatu irudia EXIF datuetan oinarrituta</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="446"/>
        <source>Individual wallpaper for each monitor</source>
        <translation>Banakako horma-papera monitore bakoitzarentzat</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="473"/>
        <source>Slide Show</source>
        <translation>Diapositiba aurkezpena</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="479"/>
        <source>Enable Slide Show</source>
        <translation>Gaitu diapositiba aurkezpena</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="491"/>
        <source>Wallpaper image folder:</source>
        <translation>Horma-irudien karpeta:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="505"/>
        <source>Browse</source>
        <translation>Arakatu</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="512"/>
        <source> hour(s)</source>
        <translation> ordua(k)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="522"/>
        <source>and</source>
        <translation>eta</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="535"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation>5min baino gutxiagoko tarteak ez dira aintzat hartuko</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="538"/>
        <source>Interval:</source>
        <translation>Tartea:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="545"/>
        <source> minute(s)</source>
        <translation> minutu(ak)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="498"/>
        <source>Wallpaper folder</source>
        <translation>Horma-paperaren karpeta</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="587"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="620"/>
        <source>Visible Shortcuts</source>
        <translation>Ikusgai dauden lasterbideak</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="626"/>
        <source>Home</source>
        <translation>Hasiera</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="637"/>
        <source>Trash</source>
        <translation>Zaborrontzia</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="648"/>
        <source>Computer</source>
        <translation>Ordenagailua</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="659"/>
        <source>Network</source>
        <translation>Sarea</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="614"/>
        <source>Advanced</source>
        <translation>Aurreratua</translation>
    </message>
</context>
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Ezkutuko lasterbideak</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="21"/>
        <source>Shortcut</source>
        <translation>Lasterbidea</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="26"/>
        <source>Action</source>
        <translation>Ekintza</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="31"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Focus view, clear filter bar</source>
        <translation>Foku ikuspegia, garbitu iragazki-barra</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Ctrl+Esc</source>
        <translation>Ctrl+Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="42"/>
        <source>Focus side-pane</source>
        <translation>Foku alboko panela</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="50"/>
        <location filename="../shortcuts.ui" line="58"/>
        <source>Focus path entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Ctrl+Tab</source>
        <translation>Ctrl+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="66"/>
        <location filename="../shortcuts.ui" line="82"/>
        <source>Next tab</source>
        <translation>Hurrengo fitxa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Ctrl+Shift+Tab</source>
        <translation>Ctrl+Shift+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="74"/>
        <location filename="../shortcuts.ui" line="90"/>
        <source>Previous tab</source>
        <translation>Aurreko fitxa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <source>Ctrl+PageDown</source>
        <translation>Ctrl+PageDown</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Ctrl+PageUp</source>
        <translation>Ctrl+PageUp</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>Ctrl+Number</source>
        <translation>Ctrl+Zenbakia</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="98"/>
        <location filename="../shortcuts.ui" line="106"/>
        <source>Jump to tab</source>
        <translation>Joan fitxara</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="103"/>
        <source>Alt+Number</source>
        <translation>Alt+Zenbakia</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="111"/>
        <source>Backspace</source>
        <translation>Atzera-espazioa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="114"/>
        <source>Go up</source>
        <translation>Igo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="119"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="122"/>
        <source>Search dialog</source>
        <translation>Bilatzeko elkarrizketa-koadroa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="127"/>
        <source>Shift+Insert</source>
        <translation>Shift+Insert</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="130"/>
        <source>Paste into transient filter bar</source>
        <translation>Itsatsi iragazki-barra iragankor batean</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="135"/>
        <source>Drop+Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="143"/>
        <source>Drop+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="151"/>
        <source>Drop+Shift+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="138"/>
        <source>Move file on dropping</source>
        <translation>Mugitu fitxategia jartzerakoan</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="146"/>
        <source>Copy file on dropping</source>
        <translation>Kopiatu fitxategia jartzerakoan</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="154"/>
        <source>Make a symlink on dropping</source>
        <translation>Jarritakoan esteka sinbolikoa egin</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Artxiboen administratzailea</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="81"/>
        <source>Recent F&amp;iles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="139"/>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="146"/>
        <source>Path &amp;Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="153"/>
        <source>&amp;Filtering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="228"/>
        <source>&amp;Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="287"/>
        <source>Go &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="290"/>
        <source>Go Up</source>
        <translation>Igo</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="293"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="302"/>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="305"/>
        <source>Alt+Home</source>
        <translation>Alt+Home</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="314"/>
        <source>&amp;Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="317"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="326"/>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="335"/>
        <source>Quit</source>
        <translation>Irten</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="344"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="353"/>
        <source>&amp;New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="356"/>
        <source>New Window</source>
        <translation>Leiho Berria</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="359"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="367"/>
        <source>Show &amp;Hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="370"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="379"/>
        <source>&amp;Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="388"/>
        <source>&amp;Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="393"/>
        <source>&amp;Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="402"/>
        <source>&amp;Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="411"/>
        <source>&amp;Add to Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="416"/>
        <source>&amp;Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="421"/>
        <source>Reload</source>
        <translation>Berriz kargatu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="429"/>
        <source>&amp;Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="437"/>
        <source>&amp;Compact View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="445"/>
        <source>&amp;Detailed List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="453"/>
        <source>&amp;Thumbnail View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="462"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="465"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="474"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="477"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="486"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="489"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="494"/>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="497"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="502"/>
        <source>De&amp;select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="505"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="510"/>
        <source>Pr&amp;eferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="518"/>
        <source>&amp;Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="526"/>
        <source>&amp;Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="534"/>
        <source>&amp;By File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="542"/>
        <source>By &amp;Modification Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>By C&amp;reation Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="558"/>
        <source>By Deletio&amp;n Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>By File &amp;Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="574"/>
        <source>By &amp;Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>By &amp;Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="590"/>
        <source>&amp;Folder First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="598"/>
        <source>&amp;Hidden Last</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="879"/>
        <source>Shift+F2</source>
        <translation>Shift+F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="963"/>
        <source>Preserve Settings Recursively from &amp;Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="968"/>
        <source>&amp;Go to Source of Inherited Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="973"/>
        <source>&amp;Remove Settings of Nonexistent Folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="981"/>
        <source>&amp;Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="651"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="700"/>
        <source>&amp;Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="708"/>
        <source>By File &amp;Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="713"/>
        <source>&amp;Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="734"/>
        <source>Open Tab in &amp;Root Instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="748"/>
        <source>&amp;Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="760"/>
        <source>&amp;Blank File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="847"/>
        <source>Preserve Settings for &amp;This Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="884"/>
        <source>&amp;Show/Focus Filter Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="887"/>
        <source>Show Filter Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="890"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="898"/>
        <source>S&amp;plit View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="901"/>
        <source>Split View</source>
        <translation>Ikuspegi Zatitua</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="904"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="909"/>
        <source>&amp;Copy Full Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="912"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="923"/>
        <source>Show Thumb&amp;nails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="926"/>
        <source>Show Thumbnails</source>
        <translation>Erakutsi Miniaturak</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="934"/>
        <source>S&amp;ide Pane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="937"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="942"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="947"/>
        <source>Open Tab in &amp;Admin Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="952"/>
        <location filename="../main-win.ui" line="955"/>
        <source>Create Launcher</source>
        <translation>Sortu Abiarazlea</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="782"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="787"/>
        <source>&amp;Clear All Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="790"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="799"/>
        <source>Close &amp;previous tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="808"/>
        <source>Close &amp;next tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="852"/>
        <source>Connect to &amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="860"/>
        <source>&amp;Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="868"/>
        <source>&amp;Path Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="873"/>
        <source>&amp;Bulk Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="876"/>
        <source>Bulk Rename</source>
        <translation>Mailan Aldatu Izena</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="813"/>
        <source>Close &amp;other tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="779"/>
        <source>Permanent &amp;filter bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="821"/>
        <source>&amp;Menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="824"/>
        <source>Menu bar</source>
        <translation>Menu-barra</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="827"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="836"/>
        <location filename="../main-win.ui" line="839"/>
        <source>Menu</source>
        <translation>Menua</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="607"/>
        <source>New &amp;Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="160"/>
        <source>&amp;Customized View Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="610"/>
        <source>New Tab</source>
        <translation>Fitxa Berria</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="613"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="622"/>
        <source>Go &amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="625"/>
        <source>Go Back</source>
        <translation>Atzera Egin</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="628"/>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="637"/>
        <source>Go &amp;Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="640"/>
        <source>Go Forward</source>
        <translation>Aurrera Joan</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="643"/>
        <source>Alt+Right</source>
        <translation>Alt+Right</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="648"/>
        <source>&amp;Invert Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="660"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="663"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="668"/>
        <source>&amp;Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="671"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="676"/>
        <source>C&amp;lose Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="684"/>
        <source>File &amp;Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="687"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="692"/>
        <source>&amp;Folder Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="721"/>
        <source>Edit Bookmarks</source>
        <translation>Editatu Laster-markak</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="726"/>
        <source>Open &amp;Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="729"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="739"/>
        <source>&amp;Edit Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="751"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="763"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="768"/>
        <source>&amp;Find Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="771"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="70"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="74"/>
        <source>C&amp;reate New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="98"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="105"/>
        <location filename="../main-win.ui" line="129"/>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="109"/>
        <source>&amp;Sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="204"/>
        <source>&amp;Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="211"/>
        <source>&amp;Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="253"/>
        <source>Main Toolbar</source>
        <translation>Tresna-barra Nagusia</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="187"/>
        <source>Name of configuration profile</source>
        <translation>Konfigurazio-profilaren Izena</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="187"/>
        <source>PROFILE</source>
        <translation>PERFILA</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Run PCManFM-Qt as a daemon</source>
        <translation>Exekutatu PCManFM-Qt deabru gisa</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Quit PCManFM-Qt</source>
        <translation>Irten PCManFM-Qt</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Launch desktop manager</source>
        <translation>Abiarazi mahaigaineko kudeatzailea</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="199"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Desaktibatu mahaigaineko kudeatzailea exekutatzen ari bada</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="202"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Ireki mahaigaineko hobespenen elkarrizketa-koadroa zehaztutako izena duen orrian</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="202"/>
        <location filename="../application.cpp" line="217"/>
        <source>NAME</source>
        <translation>IZENA</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="205"/>
        <source>Open new window</source>
        <translation>Ireki leiho berria</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="208"/>
        <source>Open Find Files utility</source>
        <translation>Ireki Bilatu fitxategiak utilitatea</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="211"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="211"/>
        <source>FILE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="214"/>
        <source>MODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="214"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="217"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Ireki Hobespenen elkarrizketa-koadroa zehaztutako izena duen orrian</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="220"/>
        <source>Files or directories to open</source>
        <translation>Ireki beharreko fitxategiak edo direktorioak</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="220"/>
        <source>[FILE1, FILE2,...]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="655"/>
        <location filename="../application.cpp" line="660"/>
        <source>Error</source>
        <translation>Errorea</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="660"/>
        <source>Terminal emulator is not set.</source>
        <translation>Terminal-emuladorea ez dago ezarrita.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>Ireki fitxategi-kudeatzailean</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="138"/>
        <source>Removable Disk</source>
        <translation>Disko Aldagarria</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation>SSH</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation>WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation>WebDav Segurua</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation>HTTPS</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.cpp" line="35"/>
        <source>Command:</source>
        <translation>Agindua:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="36"/>
        <source>The command to execute.</source>
        <translation>Exekutatu beharreko komandoa.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="40"/>
        <source>The URL to access.</source>
        <translation>Sartzeko URLa.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="67"/>
        <source>Select an icon</source>
        <translation>Hautatu ikono bat</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="69"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Irudiak (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="91"/>
        <source>Select an executable file</source>
        <translation>Hautatu fitxategi exekutagarri bat</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="99"/>
        <source>Select a file</source>
        <translation>Hautatu fitxategi bat</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>Bete atzeko planoko kolorearekin soilik</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Luzatu pantaila osoa betetzeko</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>Luzatu pantailara egokitzeko</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>Zentratu pantailan</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Lauzatu irudia pantaila osoa betetzeko</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation>Handitu irudia pantaila osoa betetzeko</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="264"/>
        <source>Select Wallpaper</source>
        <translation>Hautatu Horma-papera</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="268"/>
        <source>Image Files</source>
        <translation>Irudi fitxategiak</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="310"/>
        <source>Select Wallpaper Folder</source>
        <translation>Hautatu Horma-irudiaren Karpeta</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="303"/>
        <source>Trash (One item)</source>
        <translation>Zaborrontzia (Elementu bat)</translation>
    </message>
    <message numerus="yes">
        <location filename="../desktopwindow.cpp" line="306"/>
        <source>Trash (%Ln items)</source>
        <translation>
            <numerusform>Zaborrontzia (%Ln elementu)</numerusform>
            <numerusform>Zaborrontzia (%Ln elementu)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="310"/>
        <source>Trash (Empty)</source>
        <translation>Zaborrontzia (hutsik)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="345"/>
        <source>Computer</source>
        <translation>Ordenagailua</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="359"/>
        <source>Network</source>
        <translation>Sarea</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1011"/>
        <source>Open</source>
        <translation>Ireki</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1017"/>
        <location filename="../desktopwindow.cpp" line="1057"/>
        <source>Stic&amp;k to Current Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1025"/>
        <source>Empty Trash</source>
        <translation>Hustu Zakarrontzia</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1084"/>
        <source>Hide Desktop Items</source>
        <translation>Ezkutatu Mahaigaineko Elementuak</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1090"/>
        <source>Create Launcher</source>
        <translation>Sortu Abiarazlea</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1093"/>
        <source>Desktop Preferences</source>
        <translation>Mahaigaineko Hobespenak</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterBar</name>
    <message>
        <location filename="../tabpage.cpp" line="95"/>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterEdit</name>
    <message>
        <location filename="../tabpage.cpp" line="65"/>
        <source>Clear text (Ctrl+K or Esc)</source>
        <translation>Garbitu testua (Ktrl+K edo Esc)</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Root Instance</source>
        <translation>Root Instantzia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Hide menu bar</source>
        <translation>Ezkutatu menu-barra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>Honek menu-barra guztiz ezkutatuko du, erabili Ctrl+M berriro erakusteko.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1228"/>
        <source>Version: %1</source>
        <translation>Bertsioa: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2203"/>
        <source>&amp;Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2203"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2039"/>
        <source>Customized View Settings</source>
        <translation>Ikuspegi Pertsonalizatuaren Ezarpenak</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2310"/>
        <location filename="../mainwindow.cpp" line="2318"/>
        <source>Error</source>
        <translation>Errorea</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2318"/>
        <source>Switch user command is not set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2420"/>
        <source>Cleaning Folder Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2421"/>
        <source>Do you want to remove settings of nonexistent folders?
They might be useful if those folders are created again.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Compact View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Thumbnail View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="209"/>
        <source>Detailed List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="279"/>
        <source>Remove if added by user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="303"/>
        <source>Open user-defined list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="443"/>
        <source>Search Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="446"/>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="450"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="453"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="456"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="462"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="553"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="562"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="579"/>
        <source>%n item(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="581"/>
        <source> (%n hidden)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="586"/>
        <location filename="../tabpage.cpp" line="789"/>
        <location filename="../tabpage.cpp" line="803"/>
        <source>Link to</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="815"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>%n elementu hautatuta</numerusform>
            <numerusform>%n elementu hautatu dira</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="59"/>
        <source>Many files</source>
        <translation>Fitxategi asko</translation>
    </message>
    <message numerus="yes">
        <location filename="../view.cpp" line="60"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>%1 fitxategi hau ireki nahi duzu?</numerusform>
            <numerusform>%1 fitxategi hauek ireki nahi dituzu?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../view.cpp" line="122"/>
        <source>Open in New T&amp;ab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view.cpp" line="126"/>
        <source>Open in New Win&amp;dow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view.cpp" line="134"/>
        <location filename="../view.cpp" line="152"/>
        <source>Open in Termina&amp;l</source>
        <translation>Ireki Termina&amp;lean</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Erabiltzaile Interfazea</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Portaera</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="642"/>
        <source>Thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>Bolumena</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Aurreratua</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="222"/>
        <source>Select newly created files</source>
        <translation>Hautatu sortu berri diren fitxategiak</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="296"/>
        <source>Icons</source>
        <translation>Ikonoak</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="328"/>
        <source>Size of big icons:</source>
        <translation>Ikono handien tamaina:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="345"/>
        <source>Size of small icons:</source>
        <translation>Ikono txikien tamaina:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="362"/>
        <source>Size of thumbnails:</source>
        <translation>Irudi txikien tamaina:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="376"/>
        <source>Size of side pane icons:</source>
        <translation>Alboko panelen ikonoen tamaina:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Icon theme:</source>
        <translation>Ikonoaren gaia:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="546"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="559"/>
        <source>Always show the tab bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="566"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="580"/>
        <source>Remember the size of the last closed window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Default width of new windows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Default height of new windows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="93"/>
        <source>Open files with single click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="162"/>
        <source>Default view mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="119"/>
        <source> sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="175"/>
        <source>File Operations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="181"/>
        <source>Confirm before deleting files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="188"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Show thumbnails of files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="658"/>
        <source>Only show thumbnails for local files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>If this is unchecked, the DE setting will be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="103"/>
        <location filename="../preferences.ui" line="116"/>
        <source>Set to zero to disable auto-selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="106"/>
        <source>Delay of auto-selection in single click mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="144"/>
        <source>Open in current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="149"/>
        <source>Open in new tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="154"/>
        <source>Open in new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="195"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="202"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="209"/>
        <location filename="../preferences.ui" line="409"/>
        <location filename="../preferences.ui" line="419"/>
        <source>Requires application restart to take effect completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="212"/>
        <source>Launch executable files without prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>Renamed files will also be selected</source>
        <translation>Izena aldatutako fitxategiak ere hautatuko dira</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="244"/>
        <source>Number of recent files:</source>
        <translation>Azken fitxategi kopurua:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <location filename="../preferences.ui" line="335"/>
        <source>Used by Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="342"/>
        <location filename="../preferences.ui" line="352"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>Ikuspegi trinkoa eta zerrenda ikuspegi xehatua erabiltzen da</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="359"/>
        <location filename="../preferences.ui" line="369"/>
        <source>Used by Thumbnail View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>User interface</source>
        <translation>Erabiltzaile interfazea</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="402"/>
        <source>Treat backup files as hidden</source>
        <translation>Segurtasun-kopiaren artxiboak ezkutu gisa tratatzea</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="422"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Erakutsi ezkutuko fitxategien ikonoak itzalpean</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Minimum item margins in icon view:</source>
        <translation>Elementuaren gutxieneko marjinak ikonoen ikuspegian:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="466"/>
        <source>3 px by default.</source>
        <translation>3 px lehenespenez.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="469"/>
        <location filename="../preferences.ui" line="493"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="482"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="489"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>3 px lehenespenez.
3 testu-lerroetarako tarte bat ere gordetzen da.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="506"/>
        <source>Lock</source>
        <translation>Blokeatu</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="555"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>Hautatu gabe dagoenean, fitxa-barra erakutsiko da
fitxa bat baino gehiago badaude soilik.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="573"/>
        <source>Switch to newly opened tab</source>
        <translation>Aldatu ireki berri den fitxara</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="615"/>
        <source>Reopen last window tabs in a new window</source>
        <translation>Ireki berriro leihoko azken fitxak leiho berri batean</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="665"/>
        <location filename="../preferences.ui" line="677"/>
        <source>The built-in thumbnailer makes thumbnails of images that are supported by Qt.

Usually, most image types are supported. The default size limit is 4 MiB.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="670"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="682"/>
        <location filename="../preferences.ui" line="718"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="698"/>
        <location filename="../preferences.ui" line="710"/>
        <source>If existing, external thumbnailers are used for videos, PDF documents, etc.

A value of -1 means that there is no limit for the file size (the default).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="703"/>
        <source>File size limit for external thumbnailers:</source>
        <translation>Fitxategien tamainaren muga kanpoko koadro txikietarako:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="715"/>
        <source>No limit</source>
        <translation>Mugarik ez</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="860"/>
        <source>Examples:&lt;br&gt;For terminal: &lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;For switching user: &lt;i&gt;lxsudo %s&lt;/i&gt; or &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt; is the command line you want to execute with terminal or su.&lt;br&gt; Important: Please use lxsudo, sudo alone will wreck permissions of the settings file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="919"/>
        <source>Search</source>
        <translation>Bilatu</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="934"/>
        <source>Maximum search history:</source>
        <translation>Gehienezko bilaketa-historia:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="948"/>
        <source>Clear search history</source>
        <translation>Garbitu bilaketa-historia</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="983"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Aplikazioa berrabiarazi behar da aldaketak eragina izan dezan.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="136"/>
        <source>Bookmarks menu:</source>
        <translation>Laster-marken menua:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="129"/>
        <source>Show folder context menu with Ctrl + right click</source>
        <translation>Erakutsi karpetaren testuinguru-menua Ctrl + eskuineko botoiarekin</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="229"/>
        <source>Open folders in new tabs as far as possible</source>
        <translation>Ireki karpetak fitxa berrietan ahal den neurrian</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Single window mode</source>
        <translation>Leiho bakarreko modua</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="412"/>
        <source>Always show real file names</source>
        <translation>Erakutsi beti benetako fitxategi-izenak</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="429"/>
        <source>Do not show file tooltips</source>
        <translation>Ez erakutsi fitxategien argibideak</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="436"/>
        <source>Disable smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="648"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="754"/>
        <source>Auto Mount</source>
        <translation>Auto Muntaia</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="760"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="767"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Muntatu euskarri aldagarriak automatikoki sartzen direnean</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="774"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Erakutsi euskarri aldagarrietarako eskuragarri dauden aukerak sartzen direnean</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="784"/>
        <source>When removable medium unmounted:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="790"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="797"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="824"/>
        <source>Programs</source>
        <translation>Programak</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="833"/>
        <source>Terminal emulator:</source>
        <translation>Terminal emuladorea:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="847"/>
        <source>Switch &amp;user command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="873"/>
        <source>Archiver in&amp;tegration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="889"/>
        <source>Templates</source>
        <translation>Txantiloiak</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="895"/>
        <source>Show only user defined templates in menu</source>
        <translation>Erakutsi erabiltzaileak definitutako txantiloiak soilik menuan</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="902"/>
        <source>Show only one template for each MIME type</source>
        <translation>Erakutsi txantiloi bakarra MIME mota bakoitzeko</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="909"/>
        <source>Run default application after creation from template</source>
        <translation>Exekutatu aplikazio lehenetsia txantiloitik sortu ondoren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="395"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Renaming files...</source>
        <translation>Fitxategien izena aldatzen...</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Warning</source>
        <translation>Abisua</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Renaming is aborted.</source>
        <translation>Izena aldatzea bertan behera utzi da.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <location filename="../bulkrename.cpp" line="124"/>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Error</source>
        <translation>Errorea</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <source>No file could be renamed.</source>
        <translation>Ezin izan da fitxategirik aldatu.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="124"/>
        <source>Some files could not be renamed.</source>
        <translation>Fitxategi batzuei ezin izan zaie izena aldatu.</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Cannot open as Admin.</source>
        <translation>Ezin da ireki administratzaile gisa.</translation>
    </message>
</context>
</TS>
